import _extends from "@babel/runtime/helpers/extends";
import _assertThisInitialized from "@babel/runtime/helpers/assertThisInitialized";
import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import React from "react";
import classnames from "classnames";
import omit from "lodash/omit";
import warning from "warning";
import TextArea from "./TextArea";
export function fixControlledValue(value) {
  if (typeof value === "undefined" || value === null) {
    return "";
  }

  return value;
}

function shouldAffixWrapped(props) {
  return !!(props.prefix || props.suffix);
}

var Input = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(Input, _React$Component);

  function Input() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;

    _defineProperty(_assertThisInitialized(_this), "state", {
      value: _this.props.defaultValue
    });

    _defineProperty(_assertThisInitialized(_this), "inputRef", /*#__PURE__*/React.createRef());

    _defineProperty(_assertThisInitialized(_this), "handleKeyDown", function (e) {
      var _this$props = _this.props,
          onPressEnter = _this$props.onPressEnter,
          onKeyDown = _this$props.onKeyDown;

      if (e.keyCode === 13 && onPressEnter) {
        onPressEnter(e);
      }

      if (onKeyDown) {
        onKeyDown(e);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "handleChange", function (e) {
      _this.setValue(e.target.value, e);
    });

    return _this;
  }

  Input.getDerivedStateFromProps = function getDerivedStateFromProps(nextProps, state) {
    return {
      value: nextProps.value === undefined ? state.value : nextProps.value
    };
  };

  var _proto = Input.prototype;

  _proto.getSnapshotBeforeUpdate = function getSnapshotBeforeUpdate(prevProps) {
    if (shouldAffixWrapped(prevProps) !== shouldAffixWrapped(this.props)) {
      process.env.NODE_ENV !== "production" ? warning(this.inputRef.current !== document.activeElement, "Input", "When Input is focused, dynamic add or remove prefix / suffix will make it lose focus caused by dom structure change.") : void 0;
    }

    return null;
  } // Since polyfill `getSnapshotBeforeUpdate` need work with `componentDidUpdate`.
  // We keep an empty function here.
  ;

  _proto.componentDidUpdate = function componentDidUpdate() {};

  _proto.focus = function focus() {
    var _this$inputRef$curren;

    (_this$inputRef$curren = this.inputRef.current) === null || _this$inputRef$curren === void 0 ? void 0 : _this$inputRef$curren.focus();
  };

  _proto.blur = function blur() {
    var _this$inputRef$curren2;

    (_this$inputRef$curren2 = this.inputRef.current) === null || _this$inputRef$curren2 === void 0 ? void 0 : _this$inputRef$curren2.blur();
  };

  _proto.select = function select() {
    var _this$inputRef$curren3;

    (_this$inputRef$curren3 = this.inputRef.current) === null || _this$inputRef$curren3 === void 0 ? void 0 : _this$inputRef$curren3.select();
  };

  _proto.componentDidMount = function componentDidMount() {};

  _proto.getInput = function getInput() {
    return this.inputRef.current;
  };

  _proto.renderPrepend = function renderPrepend() {
    var _this$props2 = this.props,
        prepend = _this$props2.prepend,
        prependProps = _this$props2.prependProps,
        prefixCls = _this$props2.prefixCls;
    return prepend ? /*#__PURE__*/React.createElement("div", _extends({}, prependProps, {
      className: classnames(prefixCls + "-prepend", prependProps === null || prependProps === void 0 ? void 0 : prependProps.className)
    }), prepend) : null;
  };

  _proto.renderAppend = function renderAppend() {
    var _this$props3 = this.props,
        append = _this$props3.append,
        appendProps = _this$props3.appendProps,
        prefixCls = _this$props3.prefixCls;
    return append ? /*#__PURE__*/React.createElement("div", _extends({}, appendProps, {
      className: classnames(prefixCls + "-append", appendProps === null || appendProps === void 0 ? void 0 : appendProps.className)
    }), append) : null;
  };

  _proto.renderPrefix = function renderPrefix() {
    var _this2 = this;

    var _this$props4 = this.props,
        prefixCls = _this$props4.prefixCls,
        prefix = _this$props4.prefix,
        prefixProps = _this$props4.prefixProps;
    return prefix ? /*#__PURE__*/React.createElement("div", _extends({}, prefixProps, {
      onMouseDown: function onMouseDown(e) {
        var _prefixProps$onMouseD;

        prefixProps === null || prefixProps === void 0 ? void 0 : (_prefixProps$onMouseD = prefixProps.onMouseDown) === null || _prefixProps$onMouseD === void 0 ? void 0 : _prefixProps$onMouseD.call(prefixProps, e);
        e.preventDefault();
      },
      onMouseUp: function onMouseUp(e) {
        var _prefixProps$onMouseD2;

        prefixProps === null || prefixProps === void 0 ? void 0 : (_prefixProps$onMouseD2 = prefixProps.onMouseDown) === null || _prefixProps$onMouseD2 === void 0 ? void 0 : _prefixProps$onMouseD2.call(prefixProps, e);
        e.preventDefault();
      },
      onClick: function onClick(e) {
        var _prefixProps$onClick;

        prefixProps === null || prefixProps === void 0 ? void 0 : (_prefixProps$onClick = prefixProps.onClick) === null || _prefixProps$onClick === void 0 ? void 0 : _prefixProps$onClick.call(prefixProps, e);

        _this2.focus();
      },
      className: classnames(prefixCls + "-prefix", prefixProps === null || prefixProps === void 0 ? void 0 : prefixProps.className)
    }), prefix) : null;
  };

  _proto.renderSuffix = function renderSuffix() {
    var _this3 = this;

    var _this$props5 = this.props,
        prefixCls = _this$props5.prefixCls,
        suffix = _this$props5.suffix,
        suffixProps = _this$props5.suffixProps;
    return suffix ? /*#__PURE__*/React.createElement("div", _extends({}, suffixProps, {
      onMouseDown: function onMouseDown(e) {
        var _suffixProps$onMouseD;

        suffixProps === null || suffixProps === void 0 ? void 0 : (_suffixProps$onMouseD = suffixProps.onMouseDown) === null || _suffixProps$onMouseD === void 0 ? void 0 : _suffixProps$onMouseD.call(suffixProps, e);
        e.preventDefault();
      },
      onMouseUp: function onMouseUp(e) {
        var _suffixProps$onMouseU;

        suffixProps === null || suffixProps === void 0 ? void 0 : (_suffixProps$onMouseU = suffixProps.onMouseUp) === null || _suffixProps$onMouseU === void 0 ? void 0 : _suffixProps$onMouseU.call(suffixProps, e);
        e.preventDefault();
      },
      onClick: function onClick(e) {
        var _suffixProps$onClick;

        suffixProps === null || suffixProps === void 0 ? void 0 : (_suffixProps$onClick = suffixProps.onClick) === null || _suffixProps$onClick === void 0 ? void 0 : _suffixProps$onClick.call(suffixProps, e);

        _this3.focus();
      },
      className: classnames(prefixCls + "-suffix", suffixProps === null || suffixProps === void 0 ? void 0 : suffixProps.className)
    }), suffix) : null;
  };

  _proto.setValue = function setValue(newValue, e, callback) {
    var _this$props6 = this.props,
        onChange = _this$props6.onChange,
        value = _this$props6.value;

    if (value === undefined) {
      this.setState({
        value: newValue
      }, callback);
    }

    if (onChange) {
      onChange(newValue, e);
    }
  };

  _proto.renderInput = function renderInput() {
    var _classnames, _classnames2;

    var props = this.props;
    var prefixCls = props.prefixCls,
        type = props.type,
        size = props.size,
        disabled = props.disabled,
        readOnly = props.readOnly,
        inputClassName = props.inputClassName,
        inputStyle = props.inputStyle,
        renderer = props.renderer;
    var value = this.state.value;
    var prefix = this.renderPrefix();
    var suffix = this.renderSuffix();
    var inputCls = classnames(prefixCls, (_classnames = {}, _classnames[prefixCls + "-" + size] = size !== "default", _classnames[prefixCls + "-disabled"] = disabled, _classnames[prefixCls + "-readonly"] = readOnly, _classnames), inputClassName);
    var restProps = omit(props, ["prefixCls", "style", "className", "prepend", "prependProps", "append", "appendProps", "defaultValue", "value", "size", "prefix", "prefixProps", "suffix", "suffixProps", "onPressEnter", "onChange", "inputClassName", "inputStyle", "renderer"]);
    var inputProps = Object.assign({}, restProps, {
      ref: this.inputRef,
      type: type,
      className: inputCls,
      style: inputStyle,
      onChange: this.handleChange,
      onKeyDown: this.handleKeyDown,
      value: fixControlledValue(value)
    });
    var Input = /*#__PURE__*/React.createElement(React.Fragment, null, prefix, renderer ? renderer(inputProps) : /*#__PURE__*/React.createElement("input", inputProps), suffix);

    if (!prefix && !suffix) {
      return Input;
    }

    var affixWrapperCls = classnames(props.className, prefixCls + "-affix-wrapper", (_classnames2 = {}, _classnames2[prefixCls + "-affix-wrapper-" + props.size] = props.size, _classnames2));
    return /*#__PURE__*/React.createElement("div", {
      className: affixWrapperCls,
      style: props.style
    }, Input);
  };

  _proto.render = function render() {
    var _classnames3;

    var _this$props7 = this.props,
        prefixCls = _this$props7.prefixCls,
        className = _this$props7.className,
        size = _this$props7.size,
        prepend = _this$props7.prepend,
        append = _this$props7.append,
        style = _this$props7.style;
    var classes = classnames((_classnames3 = {}, _classnames3[className] = className, _classnames3[prefixCls + "-wrapper"] = true, _classnames3[prefixCls + "-wrapper-" + size] = size !== "default", _classnames3[prefixCls + "-with-prepend"] = prepend, _classnames3[prefixCls + "-with-append"] = append, _classnames3));
    return /*#__PURE__*/React.createElement("div", {
      className: classes,
      style: style
    }, this.renderPrepend(), this.renderInput(), this.renderAppend());
  };

  return Input;
}(React.Component);

_defineProperty(Input, "defaultProps", {
  prefixCls: "rw-input",
  type: "text",
  disabled: false,
  defaultValue: ""
});

_defineProperty(Input, "TextArea", TextArea);

export { Input as default };