import React from "react";
import TextArea from "./TextArea";
declare type LiteralUnion<T extends U, U = string> = T | (U & {});
export declare function fixControlledValue<T>(value: T): "" | T;
export interface InputProps extends Omit<React.InputHTMLAttributes<HTMLInputElement>, "size" | "prefix" | "type" | "onChange"> {
    prefixCls?: string;
    type?: LiteralUnion<"button" | "checkbox" | "color" | "date" | "datetime-local" | "email" | "file" | "hidden" | "image" | "month" | "number" | "password" | "radio" | "range" | "reset" | "search" | "submit" | "tel" | "text" | "time" | "url" | "week">;
    prepend?: React.ReactNode;
    prependProps?: React.HTMLAttributes<HTMLElement>;
    append?: React.ReactNode;
    appendProps?: React.HTMLAttributes<HTMLElement>;
    prefix?: React.ReactNode;
    prefixProps?: React.HTMLAttributes<HTMLElement>;
    suffix?: React.ReactNode;
    suffixProps?: React.HTMLAttributes<HTMLElement>;
    size?: "small" | "default" | "large";
    inputClassName?: string;
    inputStyle?: React.CSSProperties;
    onPressEnter?: (e: React.KeyboardEvent<HTMLInputElement>) => void;
    onChange?: (value: string, e: React.SyntheticEvent) => void;
    renderer?: (props: React.InputHTMLAttributes<HTMLInputElement>) => React.ReactNode;
}
export interface InputState {
    value: InputProps["value"];
}
export default class Input extends React.Component<InputProps, InputState> {
    static defaultProps: InputProps;
    static getDerivedStateFromProps(nextProps: InputProps, state: InputState): {
        value: string | number | string[] | undefined;
    };
    static TextArea: typeof TextArea;
    state: Readonly<InputState>;
    inputRef: React.RefObject<HTMLInputElement>;
    getSnapshotBeforeUpdate(prevProps: InputProps): null;
    componentDidUpdate(): void;
    focus(): void;
    blur(): void;
    select(): void;
    handleKeyDown: (e: React.KeyboardEvent<HTMLInputElement>) => void;
    handleChange: (e: React.ChangeEvent<HTMLInputElement>) => void;
    componentDidMount(): void;
    getInput(): HTMLInputElement;
    renderPrepend(): JSX.Element | null;
    renderAppend(): JSX.Element | null;
    renderPrefix(): JSX.Element | null;
    renderSuffix(): JSX.Element | null;
    setValue(newValue: string, e: React.SyntheticEvent, callback?: () => void): void;
    renderInput(): JSX.Element;
    render(): JSX.Element;
}
export {};
